/// <reference types="ws" />
import WebSocket from 'isomorphic-ws';
import { EventEmitter } from '../class/emitter.js';
import { NostrSub } from '../class/sub.js';
import { EventFilter, EventMessage, ReceiptEnvelope, SocketConfig, SubscribeConfig, SignedEvent, UnsignedEvent } from '../types.js';
export declare class NostrSocket extends EventEmitter<{
    'cancel': [id: string, sub: NostrSub, reason: string];
    'connected': NostrSocket;
    'close': NostrSocket;
    'error': Error;
    'event': EventMessage;
    'notice': string;
    'ready': NostrSocket;
    'reject': [reason: string, event: string];
    'receipt': ReceiptEnvelope;
    'subscribe': [id: string, sub: NostrSub];
}> {
    static connect(address: string, opt?: Partial<SocketConfig>): Promise<NostrSocket>;
    static query(address: string, filter: EventFilter, opt?: Partial<SocketConfig>): Promise<SignedEvent[]>;
    readonly _opt: SocketConfig;
    _address: string | null;
    _buffer?: ReturnType<typeof setTimeout>;
    _init: boolean;
    _outbox: SignedEvent[];
    _socket: WebSocket | null;
    _subs: Map<string, NostrSub>;
    constructor(options?: Partial<SocketConfig>);
    get address(): string;
    get opt(): SocketConfig;
    get connected(): boolean;
    get ready(): boolean;
    get socket(): WebSocket;
    get subs(): Map<string, NostrSub>;
    log: {
        debug: (...s: unknown[]) => void | null;
        info: (...s: unknown[]) => void | null;
    };
    _bounce_handler(reason: string, event: string): void;
    _err_handler(err: unknown): void;
    _event_handler(payload: string[]): Promise<void>;
    _msg_handler(msg: any): void | Promise<void>;
    _cancel_handler(payload: string[]): void;
    _eose_handler(payload: string[]): void;
    _open_handler(_event: unknown): void;
    _notice_handler(payload: string[]): void;
    _receipt_handler(payload: ReceiptEnvelope): void;
    _publish(events?: SignedEvent[]): Promise<void[]>;
    _subscribe(subs?: [string, NostrSub][]): Promise<void[]>;
    cancel(sub_id: string): void;
    connect(address?: string): Promise<this>;
    close(): void;
    get_sub(sub_id: string): NostrSub;
    publish(event: SignedEvent): void;
    prefetch(filter: EventFilter, close?: boolean): Promise<SignedEvent[]>;
    send(event: UnsignedEvent, signer: (msg: string) => string | Promise<string>): Promise<unknown>;
    sign(event: UnsignedEvent, signer: (msg: string) => string | Promise<string>): Promise<{
        id: string;
        sig: string;
        content: string;
        created_at: number;
        kind: number;
        pubkey: string;
        tags: string[][];
    }>;
    subscribe(filter: EventFilter, config?: Partial<SubscribeConfig>): NostrSub;
    when_cancel(sub_id: string): Promise<unknown>;
    when_connected(): Promise<unknown>;
    when_receipt(event_id: string): Promise<unknown>;
    when_sub(sub_id: string): Promise<unknown>;
}
